@@ -227,6 +227,7 @@ void *	liqcell_gettag(liqcell *self);
 
 
 
+
 //######################################################################### ui/interaction
 void 	liqcell_setvisible(liqcell *self,int arg);				// set the visible indicator
 int    	liqcell_getvisible(liqcell *self);
@@ -237,6 +238,11 @@ int 	liqcell_getenabled(liqcell *self);
 void 	liqcell_setselected(liqcell *self,int arg);				// set the selected indicator
 int 	liqcell_getselected(liqcell *self);
 
+
+void    liqcell_child_selectall(liqcell *self);                 // allow bulk selection
+void    liqcell_child_selectnone(liqcell *self);
+void    liqcell_child_selectinv(liqcell *self);
+
 void 	liqcell_setdirty(liqcell *self,int dirty);				// set the dirty flag :)  this cascades through parents as well
 int    	liqcell_getdirty(liqcell *self);
 
@@ -318,6 +324,10 @@ int 	liqcell_child_arrange_makegrid(liqcell *self,int viscolcount,int visrowcoun
 
 
 
+
+
+
+
 //######################################################################### special handlers
 
 
