@@ -15,4 +15,12 @@ int textbox_clear(liqcell *textbox);
 int textbox_selectall(liqcell *textbox);
 int textbox_fakebackspace(liqcell *textbox);
 
+
+
+int liqlist_clear(liqcell *liqlist); 
+int liqlist_additem(liqcell *liqlist,char *item);
+int liqlist_setindex(liqcell *liqlist,int index);
+int liqlist_getindex(liqcell *liqlist);
+int liqlist_count(liqcell *liqlist);
+
 #endif
