@@ -720,6 +720,7 @@ liqcell *liqcell_findfirsthandler(liqcell*root,char *handlername)
 int liqcell_easyrun_depth=0;
 
 int liqcell_easyrun_hide_tools = 0;
+int liqcell_easyrun_hide_back = 0;
 
 /**
  * Main program event handler.
@@ -729,7 +730,7 @@ int liqcell_easyrun_hide_tools = 0;
  */
 int liqcell_easyrun(liqcell *self)
 {
-	liqapp_log("#################################### liqcell easyrun (%i,%i) :: %s",self->w,self->h,self->name);
+	liqapp_log("#################################### liqcell easyrun (%i,%i) :: %s (%i)",self->w,self->h,self->name,self->usagecount);
 	if(liqcell_showdebugboxes)
 		liqcell_print2(self);
 	if(self->w==0 || self->h==0)
@@ -752,7 +753,11 @@ int liqcell_easyrun(liqcell *self)
 		// first cell, ask if tools should be globally available
 		liqcell_easyrun_hide_tools = liqcell_propgeti(self,"easyrun_hidetools",0);
 	}
-	
+	if( liqcell_easyrun_depth == 0 )
+	{
+		// first cell, ask if tools should be globally available
+		liqcell_easyrun_hide_back = liqcell_propgeti(self,"easyrun_hideback",0);
+	}	
 	
 	// set the 
 	//liqcell_propseti(self,"dialog_complete",0);
@@ -1355,7 +1360,7 @@ waitevent:
 						
 
 							//if( (omsx<64) && ((targetsurface->height-omsy)<64) && (omex<64) && ((targetsurface->height-omey)<64) )
-							if( (omsx<64) && ((canvas.pixelheight-omsy)<64) && (omex<64) && ((canvas.pixelheight-omey)<64) )
+							if( (omsx<64) && ((canvas.pixelheight-omsy)<64) && (omex<64) && ((canvas.pixelheight-omey)<64) && (liqcell_easyrun_hide_back==0)  )
 							{
 								if(ev.mouse.pressure!=0)
 								{
@@ -1436,7 +1441,7 @@ waitevent:
 							
 						// check if we need to send click
 						//if(  (liqcell_handlerfind(self,"mouse")==NULL) || (liqstroke_totallength(mouseargs.stroke) < 25)   )
-						if(  (liqstroke_totallength(mouseargs.stroke) < 50)) //25)   )
+						if(  (liqstroke_totallength(mouseargs.stroke) < 60)) //25)   )
 						{
 							
 							char buff[256];
@@ -1607,6 +1612,9 @@ quickfin:
 					liqcell_easyrun( zoom_app );
                     
                     liqcanvas_settitle( liqcell_getcaption(self) );
+                    
+                    // Mon Sep 07 22:13:27 2009 lcuk : was not releasing... tsk tsk
+                    liqcell_release(zoom_app);
 
 					zoom_app = NULL;
 
@@ -1731,14 +1739,14 @@ moar:
 				//infotools = liqimage_cache_getfile("/usr/share/liqbase/libliqbase/media/package_system.png", 0,0,1);
                 
                 //infotools = liqimage_cache_getfile("/home/user/svn/liqbase-playground/liqbase_base_fs/usr/share/icons/hicolor/scalable/apps/liqbase_playground.png", 0,0,1);
-                infotools = liqimage_cache_getfile("/home/user/svn/liqbase-playground/media/liqbase_playground_use.png", 0,0,1);
+                infotools = liqimage_cache_getfile("/usr/share/liqbase/libliqbase/media/liqbase_playground_use.png", 0,0,1);
                 
                 
                 
 			}
 
             
-			if(infoback && infoclose)
+			if(infoback && infoclose &&     (liqcell_easyrun_hide_back==0)    )
 			{
 				//liqapp_log("************************************************************************************** use");
 				if(liqcell_easyrun_depth==1)
@@ -1747,6 +1755,8 @@ moar:
 				
 					liqcliprect_drawimagecolor(targetcr, infoback , 0,targetsurface->height-48,48,48, 1);
 			}
+            
+            
 			if( (infotools) && (liqcell_easyrun_hide_tools==0) )
 			{
 					liqcliprect_drawimagecolor(targetcr, infotools , targetsurface->width-48,0 ,48,48, 1);
@@ -1861,7 +1871,7 @@ moar:
 		}
 	}
 	liqapp_log("liqcell easyrun complete %i",result);
-	
+	liqapp_log("@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@ fin # liqcell easyrun (%i,%i) :: %s (%i)",self->w,self->h,self->name,self->usagecount);
 	
 	if( (liqcell_easyrunstack_used==1) )//&& (liqapp_pref_checkexists("noflashingcursor")==0) )
 	{
@@ -1881,6 +1891,9 @@ moar:
 	liqcell_easyrun_depth--;
 	
 	liqcell_historystore_historythumb(self);			// lol!
+
+    
+    
 	
 	return result;
 }
