@@ -41,7 +41,7 @@
 #define  GREEN    "rgb(0,173,0)"
 #define  BLUE     "rgb(0,0,255)"
 #define  YELLOW   "rgb(225,225,0)"
-#define  CYAN     "rgb(0,175,175)"
+#define  CYAN     "rgba(0,175,175,128)"
 #define  MAGENTA  "rgb(255,0,255)"
 
 
@@ -192,7 +192,12 @@ int textbox_clear(liqcell *textbox)
 		{
 			if(*key==10)
 			{
-				liqcell_handlerrun(self,"click",NULL);
+				// Wed Aug 19 00:17:53 2009 lcuk : change this now to send a different event :)
+				// Wed Aug 19 00:18:00 2009 lcuk : easier to get a special "keypress_enter" message and know what to do
+				// Wed Aug 19 00:23:07 2009 lcuk : lots of things do stuff when you press enter
+				// Wed Aug 19 00:23:17 2009 lcuk : alternative is a default button as in visual basic
+				// Wed Aug 19 00:23:41 2009 lcuk : how do i find the related default button though within the system
+				liqcell_handlerrun(self,"keypress_enter",NULL);
 				key="";
 			}
 			if(*key==8 || *key==9)
@@ -427,6 +432,7 @@ liqcell *textbox_create()
 		liqcell_propsets(  self,  "backcolor", "rgb(100,255,150)" );
 		liqcell_propsets(  self,  "textcolor", "rgb(20,30,40)" );
 		liqcell_propsets(  self,  "bordercolor", "rgb(255,255,255)" );
+		
 
 		liqcell_propseti(  self,  "selstart",  0 );
 		liqcell_propseti(  self,  "sellength", 0 );
@@ -450,6 +456,16 @@ liqcell *textbox_create()
 		liqcell_propseti(vkbd_command, "textaligny", 2);
 		liqcell_propseti(vkbd_command, "lockaspect", 1);
 		
+		if( strcasecmp("RX-34", liqapp_hardware_product_get() ) ==0 )
+		{
+			// keep visible
+		}
+		else
+		{
+			// hide
+			liqcell_setvisible(vkbd_command,0);
+		}
+		
 		liqcell_child_insert(self, vkbd_command);
 	}
 	return self;
